@@ -202,23 +202,25 @@ data_model <- function(x) {
 data_model.data.table <- function(x) {
   
   checkmate::assert_data_table(x)
-  drug_ids <- unlist(
-    gDRutils::get_env_identifiers(
-      c("drug_name", "drug_name2"), 
-      simplify = FALSE
-    )
-  )
-  cl_id <- gDRutils::get_env_identifiers("cellline")
+  
   conc2 <- gDRutils::get_env_identifiers("concentration2")
-  if (all(.get_default_combination_nested_identifiers() %in% colnames(x))) {
-    if (all(x[[conc2]]
-            %in% gDRutils::get_env_identifiers("untreated_tag"))) {
-      "single-agent"
-    } else {
-      "combination"
-    }
+  untreated_tag <- gDRutils::get_env_identifiers("untreated_tag")
+  barcode_col <- gDRutils::get_env_identifiers("barcode")
+  well_cols <- gDRutils::get_env_identifiers("well_position")
+  
+  # Check for Time-Course: defined by multiple records per well (e.g. multiple timepoints)
+  # We check for duplication in Barcode + Well identifiers
+  id_cols <- intersect(c(barcode_col, well_cols), colnames(x))
+  is_time_course <- if (length(id_cols) > 0) anyDuplicated(x, by = id_cols) > 0 else FALSE
+
+  if (is_time_course) {
+    gDRutils::get_supported_experiments("time-course")
+  } else if (all(.get_default_combination_nested_identifiers() %in% colnames(x)) &&
+             !all(x[[conc2]] %in% c(untreated_tag, 0))) {
+    # It is combination if Concentration_2 exists and is not all 0 or vehicle
+    gDRutils::get_supported_experiments("combo")
   } else if (.get_default_single_agent_nested_identifiers() %in% colnames(x)) {
-    "single-agent"
+    gDRutils::get_supported_experiments("sa")
   } else {
     stop("Unknown data model")
   }
@@ -233,6 +235,7 @@ data_model.data.table <- function(x) {
 #' @keywords utils
 #' @export
 data_model.character <- function(x) {
+  
   checkmate::assert_subset(x, gDRutils::get_supported_experiments())
   
   exp_v <- gDRutils::get_experiment_groups()
@@ -291,8 +294,8 @@ get_default_nested_identifiers.data.table <- function(x, data_model = NULL) {
   
   checkmate::assert_data_table(x)
   checkmate::assert_choice(
-    data_model, 
-    c("single-agent", "combination"), 
+    data_model,
+    gDRutils::get_supported_experiments(), 
     null.ok = TRUE
   )
   
@@ -314,12 +317,19 @@ get_default_nested_identifiers.SummarizedExperiment <- function(
 .get_default_nested_identifiers <- function(se = NULL, data_model = NULL) {
  
   checkmate::assert_choice(
-    data_model, c("single-agent", "combination"),
+    data_model, gDRutils::get_supported_experiments(),
     null.ok = TRUE
   )
  
-  ml <- list(`single-agent` = .get_default_single_agent_nested_identifiers(se),
-             combination = .get_default_combination_nested_identifiers(se))
+  tc_name <- gDRutils::get_supported_experiments("time-course")
+  sa_name <- gDRutils::get_supported_experiments("sa")
+  combo_name <- gDRutils::get_supported_experiments("combo")
+
+  ml <- list()
+  ml[[sa_name]] <- .get_default_single_agent_nested_identifiers(se)
+  ml[[combo_name]] <- .get_default_combination_nested_identifiers(se)
+  ml[[tc_name]] <- .get_default_combination_nested_identifiers(se)
+
   if (is.null(data_model)) {
     ml
   } else {
